@@ -435,10 +435,10 @@ class Cursor(DBAPICursor):
         return rows_to_return
 
     def explain(self):
-        return self.connection.client.explain(self._query_id)
+        return self.connection.client.explain(self.connection.get_session_id, self._query_id)
 
     def explain_analyse(self):
-        return self.connection.client.explainAnalyze(self._query_id)
+        return self.connection.client.explainAnalyze(self.connection.get_session_id, self._query_id)
 
 
 def poll(self, get_progress_update=True):
@@ -475,18 +475,20 @@ for type_id in PRIMITIVE_TYPES:
     setattr(sys.modules[__name__], name, DBAPITypeObject([name]))
 
 if __name__ == '__main__':
-    host = '192.168.0.141'
+    # host = '192.168.0.141'
+    host = '18.234.120.217'
+    # host = '54.209.32.10'
     database = 'tpcds_1000'
     e6x_connection = connect(
         host=host,
         port=9000,
         scheme="e6xdb",
-        username="admin",
+        username="vishal@e6x.io",
         database=database,
         auth=None,
         configuration=None,
         kerberos_service_name=None,
-        password="admin",
+        password="75cei^%$TREdgfhU&T^RTYDrchfgvjy65dhcgf",
         check_hostname=None,
         ssl_cert=None,
         thrift_transport=None
@@ -504,6 +506,7 @@ if __name__ == '__main__':
     print('qid', qid)
     all_records = cursor.fetchone()
     print(all_records)
+    print(cursor.explain())
     cursor.clear()
     e6x_connection.close()
     exit()
